from ase.build import add_adsorbate
from ase.atoms import Atoms
import copy

def safe_add_adsorbate(base:Atoms, base_index:int, ads:Atoms, ads_index:int, bond_length:float) -> Atoms:
    base_position = (base[base_index].position[0], base[base_index].position[1])
    copied_base = copy.deepcopy(base)
    copied_ads = copy.deepcopy(ads)
    add_adsorbate(copied_base, copied_ads, position=base_position, height=bond_length, mol_index=ads_index)
    return copied_base


from ase.atoms import Atoms
import copy

def safe_remove_atom_by_index(structure:Atoms, index:int) -> Atoms:
    copied_structure = copy.deepcopy(structure)
    copied_structure.pop(index)
    return copied_structure



from ase.atoms import Atoms
import copy

def safe_euler_rotation(structure:Atoms, phi:float, theta:float, psi:float) -> Atoms:
    copied_structure = copy.deepcopy(structure)
    copied_structure.euler_rotate(phi, theta, psi)
    return copied_structure


from setuptools import setup, find_packages

VERSION = '0.0.1' 
DESCRIPTION = 'safe_ase'
LONG_DESCRIPTION = 'helper functions wrapping ase fucntions that dont overwrite original structure'

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="safe_ase", 
        version=VERSION,
        author="Roberto Rousse",
        author_email="<roberto.rousse@gmail.com>",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=[
            'ase',
        ],
        keywords=['python', 'first package'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Programming Language :: Python :: 3",
        ]
)